beamprofiler.iso.characterizing\_parameters.edge\_steepness
===========================================================

.. currentmodule:: beamprofiler.iso.characterizing_parameters

.. autofunction:: edge_steepness